Description Usage Arguments Details Value See Also Examples
View source: R/tadaa_omnibus.R
Performs one-, two-way or factorial ANOVA with adjustable sums of squares method and optionally displays effect sizes ((partial) η^2 and Cohen's f).
1 2 3 4 5 6 7 8 9 |
formula |
Formula for model, passed to |
data |
Data for model. |
show_effect_size |
If |
factorize |
If |
type |
Which type of SS to use. Default is |
check_contrasts |
Only applies to |
print |
Print method, default |
If a specified independent variable is not properly encoded as a factor, it is
automatically converted if factorize = TRUE to ensure valid results.
If type = 3 and check_contrasts = TRUE, the "contrasts" of
each non-ordered factor will be checked and set to contr.sum to ensure the function
yields usable results. It is highly recommended to only use check_contrasts = FALSE
for debugging or educational purposes, or of you know what you're doing and using
your own contrast matrix.
A data.frame by default, otherwise dust object, depending on print.
Other Tadaa-functions:
tadaa_chisq(),
tadaa_kruskal(),
tadaa_levene(),
tadaa_nom(),
tadaa_one_sample(),
tadaa_ord(),
tadaa_pairwise_tukey(),
tadaa_pairwise_t(),
tadaa_t.test(),
tadaa_wilcoxon()
1 2 3 4 5 6 7 8 9 10 11 12 13 | tadaa_aov(stunzahl ~ jahrgang, data = ngo)
tadaa_aov(stunzahl ~ jahrgang * geschl, data = ngo)
# Other types of sums and print options
## Not run:
tadaa_aov(stunzahl ~ jahrgang * geschl, data = ngo, type = 1, print = "console")
tadaa_aov(stunzahl ~ jahrgang * geschl, data = ngo, type = 3, print = "console")
tadaa_aov(stunzahl ~ jahrgang * geschl,
data = ngo,
type = 3, check_contrasts = FALSE, print = "console"
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.